This function uploads a local data frame into a remote data source, creating the table definition as needed. If the table exists, it will append the data to the existing table. If not, it will create a new table.
# S3 method for kusto_database_endpoint
copy_to(
dest,
df,
name = deparse(substitute(df)),
overwrite = FALSE,
method = "inline",
...
)remote data source
local data frame
Name for new remote table
If TRUE, will overwrite an existing table with
name name. If FALSE, will throw an error if name already
exists.
For local ingestion, the method to use. "inline", "streaming", or "indirect".
other parameters passed to the query
collect() for the opposite action; downloading remote data into a local tbl.